### A python library for geospatial processing based GDAL and Google Earth Engine
=======================

Installation
-----

```bash
pip install geospace -U
```

To Do
-----

-   Time series extration using Google Earth Engine.

Pull requests are encouraged!

License
-------

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any means.